==> haskell-hls-module-name-plugin-2.1.0.0-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-5WVo8Is5AUP8sdT76BlGih
key:                  hls-module-name-plugin-2.1.0.0-5WVo8Is5AUP8sdT76BlGih
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e658f74db2bbe015fa89a5dedf0dac9f
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-5WVo8Is5AUP8sdT76BlGih
depends:
    aeson-2.1.2.1-3LOl3stht3x9JybSpHkoQT base-4.17.2.1 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.1.0.0-CtyDzgoNpaj9hnzmEu5haa
    hls-plugin-api-2.1.0.0-T15pG4rcLPC7cG4LNTB8t
    lsp-2.1.0.0-AW1b6Rq1CNJFsxquT5PTmX text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.1.0.0-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-DsT3w9b6sdx84FfLp5jMYD
key:                  hls-module-name-plugin-2.1.0.0-DsT3w9b6sdx84FfLp5jMYD
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9e007ed7c8df944856870463cdd58d6b
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-DsT3w9b6sdx84FfLp5jMYD
depends:
    aeson-2.1.2.1-3LOl3stht3x9JybSpHkoQT base-4.17.2.1 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.1.0.0-4sl3fYi1qNUA5HGuWo4OFR
    hls-plugin-api-2.1.0.0-7aZtfT4qkwcHbuFQN5uNhG
    lsp-2.1.0.0-FvkhfFKpPZpLgDTU1FJfIS text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
